==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/fe/ItemWidget.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 */

/**
 * API Status: **Private**
 * @module nmodule/nss/rc/fe/ItemWidget
 */
define(['jquery', 'Promise', 'bajaux/Widget', 'nmodule/webEditors/rc/fe/BaseWidget', 'nmodule/webEditors/rc/fe/fe', 'nmodule/nss/rc/fe/SeverityWidget', 'nmodule/nss/rc/model/Item', 'lex!nss', 'css!nmodule/nss/rc/nss'], function ($, Promise, Widget, BaseWidget, fe, SeverityWidget, Item, lexicon) {
  'use strict';

  var _lexicon = _slicedToArray(lexicon, 1),
    nssLex = _lexicon[0];
  /**
   * Returns an ItemWidget for an independent item & displays { SeverityIcon -> Item } on the UI.
   *
   * @class
   * @alias module:nmodule/nss/rc/fe/ItemWidget
   * @extends module:nmodule/webEditors/rc/fe/BaseWidget
   */
  return /*#__PURE__*/function (_BaseWidget) {
    function ItemWidget() {
      _classCallCheck(this, ItemWidget);
      return _callSuper(this, ItemWidget, arguments);
    }
    _inherits(ItemWidget, _BaseWidget);
    return _createClass(ItemWidget, [{
      key: "doInitialize",
      value:
      /**
       * Adds the 'ItemWidget' class to the dom.
       * @param {JQuery} dom - Html to fill.
       * @returns {Promise} Initialization promise of the SeverityWidget.
       */
      function doInitialize(dom) {
        dom.addClass('ItemWidget');
        var severityElement = $('<div/>').addClass('SeverityWidget'),
          itemElement = $('<div/>').addClass('ItemContainer'),
          summarySpan = $('<span/>').addClass('summary'),
          descriptionSpan = $('<span/>').addClass('description');
        itemElement.append(summarySpan);
        itemElement.append(descriptionSpan);
        dom.append(severityElement);
        dom.append(itemElement);
        return new SeverityWidget().initialize(dom.find('.SeverityWidget'));
      }
    }, {
      key: "doLoad",
      value:
      /**
       * Creates the ItemWidget for the input Item
       * @param {module:nmodule/nss/rc/model/Item} item - Display line item with a summary, description and severity.
       * @returns {Promise} Rendered ItemWidget wrapped as a Promise (or) a error if the input is not an Item type.
       */
      function doLoad(item) {
        var _this = this;
        if (!(item instanceof Item)) {
          throw new Error(nssLex.get('SecurityDashboardView.itemWidget.item.required.error'));
        }
        return this.$getSeverityWidget().load(item.getSeverity()).then(function () {
          _this.jq().find('.ItemContainer .summary').text(item.getSummary());
          _this.jq().find('.ItemContainer .description').text(item.getDescription());
        });
      }
    }, {
      key: "doDestroy",
      value:
      /**
       * Removes the class from the jq() at the end of widget life cycle.
       */
      function doDestroy() {
        this.jq().removeClass('ItemWidget');
        return this.$getSeverityWidget().destroy();
      }
    }, {
      key: "$getSeverityWidget",
      value:
      /**
       * Returns a severity widget.
       * @private
       * @return {module:nmodule/nss/rc/fe/SeverityWidget} SeverityWidget that was instantiated.
       */
      function $getSeverityWidget() {
        return Widget["in"](this.jq().find('.SeverityWidget'));
      }
    }]);
  }(BaseWidget);
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/fe/ItemWidget.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 */

/**
 * API Status: **Private**
 * @module nmodule/nss/rc/fe/ItemWidget
 */
define(['jquery', 'Promise', 'bajaux/Widget', 'nmodule/webEditors/rc/fe/BaseWidget', 'nmodule/webEditors/rc/fe/fe', 'nmodule/nss/rc/fe/SeverityWidget', 'nmodule/nss/rc/model/Item', 'lex!nss', 'css!nmodule/nss/rc/nss'], function ($, Promise, Widget, BaseWidget, fe, SeverityWidget, Item, lexicon) {
  'use strict';

  var _lexicon = _slicedToArray(lexicon, 1),
    nssLex = _lexicon[0];
  /**
   * Returns an ItemWidget for an independent item & displays { SeverityIcon -> Item } on the UI.
   *
   * @class
   * @alias module:nmodule/nss/rc/fe/ItemWidget
   * @extends module:nmodule/webEditors/rc/fe/BaseWidget
   */
  return /*#__PURE__*/function (_BaseWidget) {
    function ItemWidget() {
      _classCallCheck(this, ItemWidget);
      return _callSuper(this, ItemWidget, arguments);
    }
    _inherits(ItemWidget, _BaseWidget);
    return _createClass(ItemWidget, [{
      key: "doInitialize",
      value:
      /**
       * Adds the 'ItemWidget' class to the dom.
       * @param {JQuery} dom - Html to fill.
       * @returns {Promise} Initialization promise of the SeverityWidget.
       */
      function doInitialize(dom) {
        dom.addClass('ItemWidget');
        var severityElement = $('<div/>').addClass('SeverityWidget'),
          itemElement = $('<div/>').addClass('ItemContainer'),
          summarySpan = $('<span/>').addClass('summary'),
          descriptionSpan = $('<span/>').addClass('description');
        itemElement.append(summarySpan);
        itemElement.append(descriptionSpan);
        dom.append(severityElement);
        dom.append(itemElement);
        return new SeverityWidget().initialize(dom.find('.SeverityWidget'));
      }

      /**
       * Creates the ItemWidget for the input Item
       * @param {module:nmodule/nss/rc/model/Item} item - Display line item with a summary, description and severity.
       * @returns {Promise} Rendered ItemWidget wrapped as a Promise (or) a error if the input is not an Item type.
       */
    }, {
      key: "doLoad",
      value: function doLoad(item) {
        var _this = this;
        if (!(item instanceof Item)) {
          throw new Error(nssLex.get('SecurityDashboardView.itemWidget.item.required.error'));
        }
        return this.$getSeverityWidget().load(item.getSeverity()).then(function () {
          _this.jq().find('.ItemContainer .summary').text(item.getSummary());
          _this.jq().find('.ItemContainer .description').text(item.getDescription());
        });
      }

      /**
       * Removes the class from the jq() at the end of widget life cycle.
       */
    }, {
      key: "doDestroy",
      value: function doDestroy() {
        this.jq().removeClass('ItemWidget');
        return this.$getSeverityWidget().destroy();
      }

      /**
       * Returns a severity widget.
       * @private
       * @return {module:nmodule/nss/rc/fe/SeverityWidget} SeverityWidget that was instantiated.
       */
    }, {
      key: "$getSeverityWidget",
      value: function $getSeverityWidget() {
        return Widget["in"](this.jq().find('.SeverityWidget'));
      }
    }]);
  }(BaseWidget);
});
